@@ -8,8 +8,8 @@ DEFAULTS = {
     'THROTTLING_FAILURE_VIEW': 'security.throttling.views.throttling_failure_view',
     'LOG_REQUEST_IGNORE_IP': (),
     'LOG_REQUEST_IGNORE_URL_PATHS': (),
-    'LOG_REQUEST_BODY_LENGTH': 1000,
-    'LOG_RESPONSE_BODY_LENGTH': 1000,
+    'LOG_REQUEST_BODY_LENGTH': 10000,
+    'LOG_RESPONSE_BODY_LENGTH': 10000,
     'LOG_RESPONSE_BODY_CONTENT_TYPES': (
         'application/json', 'application/xml', 'text/xml', 'text/csv',
     ),
@@ -49,16 +49,19 @@ DEFAULTS = {
     'AUTO_GENERATE_TASKS_FOR_DJANGO_COMMANDS': {},
     'CELERY_HEALTH_CHECK_DEFAULT_QUEUE': getattr(django_settings, 'CELERY_DEFAULT_QUEUE', 'default'),
     'LOG_DB_NAME': None,
-    'PURGE_LOG_BACKUP_BATCH': 10000,
-    'PURGE_LOG_DELETE_BATCH': 1000,
+    'CLEAN_LOGS_BACKUP_FILE_BATCH_SIZE': 10000,
     'TASK_LOGGER_NAME': 'security.task',
     'TASK_USE_PRE_COMMIT': False,
     'ELASTICSEARCH_DATABASE': None,
     'ELASTICSEARCH_LOGSTASH_WRITER': False,
     'ELASTICSEARCH_AUTO_REFRESH': False,
-    'ELASTICSERACH_BACKUP_BATCH_SIZE': 1000,
-    'ELASTICSERACH_DELETE_BATCH_SIZE': 1000,
-    'ELASTICSERACH_MAX_NUMBER_OF_TERMS': 65536,
+    'ELASTICSEARCH_CLEAN_LOGS_READ_BATCH_SIZE': 1000,
+    'ELASTICSEARCH_CLEAN_LOGS_DELETE_BATCH_SIZE': 1000,
+    'ELASTICSEARCH_CLEAN_LOGS_DELETE_REQUEST_TIMEOUT': 30,
+    'ELASTICSEARCH_CLEAN_LOGS_DELETE_ATTEMPTS': 10,
+    'ELASTICSEARCH_CLEAN_LOGS_DELETE_ATTEMPT_SLEEP': 5,
+    'ELASTICSEARCH_MAX_NUMBER_OF_TERMS': 65536,
+    'SQL_CLEAN_LOGS_DELETE_BATCH_SIZE': 1000,
     'BACKEND_WRITERS': None,
     'BACKEND_READER': None,
     'LOG_STRING_IO_FLUSH_TIMEOUT': 5,
@@ -66,6 +69,9 @@ DEFAULTS = {
     'RELEASE': None,
     'LOG_MAX_REVISIONS_COUNT': 20,
     'RAISE_WRITER_EXCEPTIONS': False,
+    'THROTTLING_ENABLED': True,
+    'LOG_STRING_OUTPUT_TRUNCATE_LENGTH': 10000,
+    'LOG_STRING_OUTPUT_TRUNCATE_OFFSET': 1000,
 }
 
 
